#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.15.0.0
visibility:           public
id:                   apply-refact-0.15.0.0-EnGcmKBz4nx1OjxMQlH4zR
key:                  apply-refact-0.15.0.0-EnGcmKBz4nx1OjxMQlH4zR
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  0201205fd18334cd198551e96f2cc677
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/apply-refact-0.15.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/apply-refact-0.15.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/apply-refact-0.15.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.15.0.0-EnGcmKBz4nx1OjxMQlH4zR
depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    filemanip-0.3.6.3-EsLHhvyOnzyGnBJu9wfi9i ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-Ag67m4VkTysHJaCSg4DehN
    process-1.6.19.0 refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE transformers-0.6.1.0
    uniplate-1.6.13-JHjKR1RMN7w1LfjZKHnKKi
    unix-compat-0.7.4.1-EyHNw9oGSnZGifmmgNTG2S

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

